==> react-atom-slider-1.17.0.tgz: package/lib/createHandler.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { lazy, Suspense } from 'react';
import Handle from 'rc-slider/lib/Handle';
var Tooltip = /*#__PURE__*/lazy(function () {
  return import('rc-tooltip');
});

var createHandler = function createHandler(refAtomSlider, hideTooltip) {
  return function (props) {
    var value = props.value,
        index = props.index,
        dragging = props.dragging,
        restProps = _objectWithoutPropertiesLoose(props, ["value", "index", "dragging"]); // eslint-disable-line


    if (!(refAtomSlider != null && refAtomSlider.current)) {
      return null;
    }

    if (hideTooltip) {
      return Handle ? /*#__PURE__*/_jsx(Suspense, {
        fallback: null,
        children: /*#__PURE__*/_jsx(Handle, _extends({
          value: value
        }, restProps, {
          dragging: dragging.toString()
        }))
      }) : null;
    }

    return Handle ? /*#__PURE__*/_jsx(Suspense, {
      fallback: null,
      children: /*#__PURE__*/_jsx(Tooltip, {
        getTooltipContainer: function getTooltipContainer() {
          return refAtomSlider.current;
        },
        overlay: value,
        placement: "top",
        prefixCls: "rc-slider-tooltip",
        visible: true,
        children: /*#__PURE__*/_jsx(Handle, _extends({
          value: value
        }, restProps, {
          dragging: dragging.toString()
        }))
      }, index)
    }) : null;
  };
};

export default createHandler;

==> react-atom-slider-1.19.0.tgz: package/lib/createHandler.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["value", "index", "dragging"];
import { lazy, Suspense } from 'react';
import Handle from 'rc-slider/lib/Handle';
import { jsx as _jsx } from "react/jsx-runtime";
var Tooltip = /*#__PURE__*/lazy(function () {
  return import('rc-tooltip');
});

var createHandler = function createHandler(refAtomSlider, hideTooltip) {
  return function (props) {
    var value = props.value,
        index = props.index,
        dragging = props.dragging,
        restProps = _objectWithoutPropertiesLoose(props, _excluded); // eslint-disable-line


    if (!(refAtomSlider != null && refAtomSlider.current)) {
      return null;
    }

    if (hideTooltip) {
      return Handle ? /*#__PURE__*/_jsx(Suspense, {
        fallback: null,
        children: /*#__PURE__*/_jsx(Handle, _extends({
          value: value
        }, restProps, {
          dragging: dragging.toString()
        }))
      }) : null;
    }

    return Handle ? /*#__PURE__*/_jsx(Suspense, {
      fallback: null,
      children: /*#__PURE__*/_jsx(Tooltip, {
        getTooltipContainer: function getTooltipContainer() {
          return refAtomSlider.current;
        },
        overlay: value,
        placement: "top",
        prefixCls: "rc-slider-tooltip",
        visible: true,
        children: /*#__PURE__*/_jsx(Handle, _extends({
          value: value
        }, restProps, {
          dragging: dragging.toString()
        }))
      }, index)
    }) : null;
  };
};

export default createHandler;
